# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/chaostoolkit/chaosplatform-grpc/compare/0.3.0...HEAD

## [0.3.0][] - 2019-03-29

[0.2.0]: https://github.com/chaostoolkit/chaosplatform-auth/compare/0.2.0...0.3.0

### Changed

-  Updated to latest protos definition

## [0.2.0][] - 2019-01-16

[0.2.0]: https://github.com/chaostoolkit/chaosplatform-auth/compare/0.1.1...0.2.0

### Changed

-  Updated to latest protos definition

## [0.1.1][] - 2019-01-12

[0.1.1]: https://github.com/chaostoolkit/chaosplatform-grpc/compare/0.1.0...0.1.1

### Changed

-   Add protobuf dependency

## [0.1.0][] - 2018-12-19

[0.1.0]: https://github.com/chaostoolkit/chaosplatform-grpc/tree/0.1.0

### Added

-   Initial release